@@ -1,6 +1,7 @@
 from contextlib import ContextDecorator
 
-from boto3_fixtures import awslambda, dynamodb, kinesis, s3, sqs
+import boto3_fixtures as b3f
+from boto3_fixtures import awslambda, dynamodb, kinesis, s3, sns, sqs
 
 SERVICES = {
     "lambda": awslambda,
@@ -8,6 +9,7 @@ SERVICES = {
     "kinesis": kinesis,
     "s3": s3,
     "sqs": sqs,
+    "sns": sns,
 }
 
 
@@ -19,7 +21,9 @@ class Service(ContextDecorator):
             self.kwargs = kwargs
             self.state = None
         except KeyError as e:
-            raise Exception(f"Service '{service}' is not supported.") from e
+            raise b3f.exceptions.UnsupportedServiceException(
+                f"Service '{service}' is not supported."
+            ) from e
 
     def __enter__(self):
         self.state = self.service.setup(*self.args, **self.kwargs)
