@@ -24,7 +24,7 @@ def _set_env(env, overwrite=True):
     state = {}
     for k, v in env.items():
         state[k] = os.environ[k] if k in os.environ else None
-        if state[k] is None and overwrite is False:
+        if state[k] is not None and overwrite is False:
             continue
         os.environ[k] = str(v)
         logging.getLogger().debug(f"os.environ[{k}] = {v}")
@@ -43,7 +43,7 @@ def _reset_env(env, state):
 def set_env(env, overwrite=True):
     state = {}
     try:
-        state = _set_env(env)
+        state = _set_env(env, overwrite)
         yield
     finally:
         _reset_env(env, state)
@@ -97,6 +97,7 @@ def environment(
     kinesis_streams: list = [],
     dynamodb_tables: list = [],
     s3_buckets: list = [],
+    sns_topics: list = [],
 ):
     def clean(s):
         return s.upper().replace("-", "_")
@@ -111,6 +112,7 @@ def environment(
         vars.update({clean(q): q for q in sqs_queues})
         vars.update({clean(q): q for q in s3_buckets})
         vars.update({clean(t): t for t in dynamodb_tables})
+        vars.update({clean(tpc): tpc for tpc in sns_topics})
         will_overwrite = list(set(vars.keys()) & set(kwargs.keys()))
         if will_overwrite:
             logging.getLogger().warning(
